==> fet_3.12.30.orig.tar.gz: fet-3.12.30/src/interface/modifyconstraintstudentsnogapsform.h <==
/***************************************************************************
                          modifyconstraintstudentsnogapsform.h  -  description
                             -------------------
    begin                : Feb 11, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : liviu@lalescu.ro
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTSTUDENTSNOGAPSFORM_H
#define MODIFYCONSTRAINTSTUDENTSNOGAPSFORM_H

#include "modifyconstraintstudentsnogapsform_template.h"
#include "genetictimetable_defs.h"
#include "genetictimetable.h"
#include "fet.h"
#include "fetmainform.h"

#include <qcombobox.h>
#include <qmessagebox.h>
#include <qgroupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qtextedit.h>

class ModifyConstraintStudentsNoGapsForm : public ModifyConstraintStudentsNoGapsForm_template  {
public:
	ConstraintStudentsNoGaps* _ctr;

	ModifyConstraintStudentsNoGapsForm(ConstraintStudentsNoGaps* ctr);
	~ModifyConstraintStudentsNoGapsForm();

	void constraintChanged();
	void ok();
	void cancel();
};

#endif

==> fet_3.18.2.orig.tar.gz: fet-3.18.2/src/interface/modifyconstraintstudentsnogapsform.h <==
/***************************************************************************
                          modifyconstraintstudentsnogapsform.h  -  description
                             -------------------
    begin                : Feb 11, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTSTUDENTSNOGAPSFORM_H
#define MODIFYCONSTRAINTSTUDENTSNOGAPSFORM_H

#include "modifyconstraintstudentsnogapsform_template.h"
#include "genetictimetable_defs.h"
#include "genetictimetable.h"
#include "fet.h"
#include "fetmainform.h"

#include <qcombobox.h>
#include <qmessagebox.h>
#include <qgroupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qtextedit.h>

class ModifyConstraintStudentsNoGapsForm : public ModifyConstraintStudentsNoGapsForm_template  {
public:
	ConstraintStudentsNoGaps* _ctr;

	ModifyConstraintStudentsNoGapsForm(ConstraintStudentsNoGaps* ctr);
	~ModifyConstraintStudentsNoGapsForm();

	void constraintChanged();
	void ok();
	void cancel();
};

#endif
